CaptureVisionRouter class

Constructors

CaptureVisionRouter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture(dynamic data, String template) → PromiseJsImpl
The data parameter can be a file object or a DSImageData object.
getSimplifiedSettings(String templateName) → PromiseJsImpl
Retrieves the simplified runtime settings.
initSettings(String settings) → PromiseJsImpl<void>
Initializes runtime settings from a JSON string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outputSettings(String templateName) → PromiseJsImpl
Outputs the current runtime settings as a JSON string.
toString() → String
A string representation of this object.
inherited
updateSettings(String templateName, dynamic settings) → PromiseJsImpl<void>
Updates simplified runtime settings with a JSON string.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createInstance() → PromiseJsImpl<CaptureVisionRouter>
Creates a new instance of CaptureVisionRouter.