ImageData class

Constructors

ImageData()

Properties

bytes → Uint8List
no setter
format → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stride → int
no setter
width → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited